@@ -10,9 +10,9 @@
 #include <custom_conf.h>
 #else
 #define PROTOCOL_VERSION		10
-#define MARIADB_CLIENT_VERSION_STR	"10.6.8"
-#define MARIADB_BASE_VERSION		"mariadb-10.6"
-#define MARIADB_VERSION_ID		100608
+#define MARIADB_CLIENT_VERSION_STR	"10.11.8"
+#define MARIADB_BASE_VERSION		"mariadb-10.11"
+#define MARIADB_VERSION_ID		101108
 #define MARIADB_PORT	        	3306
 #define MARIADB_UNIX_ADDR               "/tmp/mysql.sock"
 #ifndef MYSQL_UNIX_ADDR
@@ -23,13 +23,13 @@
 #endif
 
 #define MYSQL_CONFIG_NAME               "my"
-#define MYSQL_VERSION_ID                100608
-#define MYSQL_SERVER_VERSION            "10.6.8-MariaDB"
+#define MYSQL_VERSION_ID                101108
+#define MYSQL_SERVER_VERSION            "10.11.8-MariaDB"
 
-#define MARIADB_PACKAGE_VERSION "3.2.8"
-#define MARIADB_PACKAGE_VERSION_ID 30208
-#define MARIADB_SYSTEM_TYPE "Linux"
-#define MARIADB_MACHINE_TYPE "x86_64"
+#define MARIADB_PACKAGE_VERSION "3.3.10"
+#define MARIADB_PACKAGE_VERSION_ID 30310
+#define MARIADB_SYSTEM_TYPE "NetBSD"
+#define MARIADB_MACHINE_TYPE "alpha"
 #define MARIADB_PLUGINDIR "/usr/pkg/lib/mysql/plugin"
 
 /* mysqld compile time options */
